import express from 'express';

import i18next from 'i18next';
import FsBackend from 'i18next-node-fs-backend';
import i18nextMiddleware from 'i18next-express-middleware';
import bodyParser from 'body-parser';


export const applyI18n = (app: ReturnType<typeof express>) => {
  i18next
    .use(FsBackend)
    .init({
      lng: 'en',
      fallbackLng: 'en',
      preload: [ 'fi', 'en' ],
      //defaultNS: 'main',
      ns: [ 'main' ],
      saveMissing: true,
      //debug: true,
      backend: {
        loadPath: 'resources/locales/{{lng}}/{{ns}}.json',
        addPath: 'resources/locales/{{lng}}/{{ns}}.missing.json'
      },
      //nsSeparator: '#||#',
      //keySeparator: '#|#'
    });

  app.use(bodyParser.json()); // for parsing application/json
  app.use(bodyParser.urlencoded({ extended: true })); // for parsing application/x-www-form-urlencoded
  app.use(i18nextMiddleware.handle(i18next, {
    // ignoreRoutes: ["/foo"],
    // removeLngFromUrl: false
  }));

  //app.use('/locales', express.static('locales'));

  app.post('/locales/add/:lng/:ns', i18nextMiddleware.missingKeyHandler(i18next));
  //app.post('/locales/add/:lng/:ns', (req, res) => {
  //  console.warn(req.query, req.body)
  //})
};
