import path from 'path';
import express from 'express';

import chalk from 'chalk';

import webpack from 'webpack';
import config from '../../webpack.config.js';


// Set up Webpack

export const applyWebpack = (app: ReturnType<typeof express>) => {
  console.log(chalk.bold('Building webpack...'));

  const compiler = webpack(Object.assign(config as object, { 
    mode: 'development' 
  }));

  app.use(require('webpack-dev-middleware')(compiler, {
    historyApiFallback: true,
    logLevel: 'warn',
    publicPath: config.output.publicPath,
    watchOptions: {
      ignored: /resources\/locales/,
    }
  }));

  app.use(require('webpack-hot-middleware')(compiler));

  // Setup static file handling
  // https://github.com/ampedandwired/html-webpack-plugin/issues/145#issuecomment-170554832
  app.use('*', function (req, res, next) {
    const filename = path.join((compiler as any).outputPath, 'index.html');
    (compiler.outputFileSystem as any).readFile(filename, (err, result) => {
      if (err) {
        return next(err);
      }
      
      res.set('content-type', 'text/html');
      res.send(result);
      res.end();
      return undefined;
    });
  });
};
