import express from 'express';
import minimist from 'minimist';
import { AddressInfo } from 'net';

import { applyI18n } from './impl/i18next';
import { applyWebpack } from './impl/webpack';
import { applyProxy } from './impl/proxy';



var argv = minimist(process.argv.slice(2), {
  default: {
    apiSecure: false,
    apiHost: 'localhost:5600',
    bindAddress: '0.0.0.0',
    port: 3000
  }
});


if (process.env.NODE_ENV === 'production') {
  throw new Error('This server is not supported in production environment');
}


// Create server
var app = express();

applyI18n(app);
applyWebpack(app);

// Set proxy
/*var proxy = new httpProxy.createProxyServer({
  target: (argv.apiSecure ? 'https://' : 'http://') + argv.apiHost
});

proxy.on('error', function (err, req, res) {
  try {
    res.end(err);
  } catch (e) { 
    //
  }
});

console.log('');

// Proxying of viewed files must be defined before the generic static file handling
app.get('/view/*', (req, res) => {
  proxy.web(req, res);
});*/

// Listen
const listener = app.listen(argv.port, argv.bindAddress, function (err) {
  const { address, port } = listener.address() as AddressInfo;
  const fullAddress = `${address}:${port}`;
  if (err) {
    console.error(`Failed to listen on ${fullAddress}: ${err}`);
    return;
  }
  
  console.log(`Listening ${fullAddress}`);
});

applyProxy(app, listener, argv);

/*listener.on('upgrade', function (req, socket, head) {
  console.log('Upgrade to websocket', req.headers['x-forwarded-for'] || req.connection.remoteAddress);
  proxy.ws(req, socket, head);
});*/

console.log('');